@@ -1,4 +1,6 @@
 from abc import abstractmethod
+from typing import (TYPE_CHECKING,
+                    List)
 
 from orient.planar import Relation
 from sect.decomposition import Location
@@ -7,6 +9,9 @@ from .geometry import Geometry
 from .hints import Coordinate
 from .primitive import Point
 
+if TYPE_CHECKING:
+    from .shaped.polygon import Polygon
+
 Relation = Relation
 Location = Location
 
@@ -122,6 +127,12 @@ class Shaped(Geometry):
         Returns perimeter of the geometry.
         """
 
+    @abstractmethod
+    def triangulate(self) -> List['Polygon']:
+        """
+        Returns triangulation of the geometry.
+        """
+
 
 class Indexable(Compound):
     __slots__ = ()
