@@ -1,5 +1,4 @@
 from functools import partial
-from itertools import chain
 from typing import (List,
                     Optional,
                     Sequence)
@@ -29,6 +28,9 @@ from gon.compound import (Compound,
                           Shaped)
 from gon.core.arithmetic import (non_negative_min,
                                  robust_divide)
+from gon.core.iterable import (flatten,
+                               to_pairs_iterable,
+                               to_pairs_sequence)
 from gon.degenerate import EMPTY
 from gon.discrete import Multipoint
 from gon.geometry import Geometry
@@ -39,9 +41,7 @@ from gon.linear import (Contour,
                         RawSegment,
                         Segment,
                         vertices)
-from gon.linear.utils import (from_raw_multisegment,
-                              to_pairs_iterable,
-                              to_pairs_sequence)
+from gon.linear.utils import from_raw_multisegment
 from gon.primitive import (Point,
                            RawPoint)
 from gon.primitive.point import point_to_step
@@ -53,8 +53,7 @@ from .polygon import (Polygon,
                       rotate_polygon_around_origin,
                       rotate_translate_polygon,
                       scale_polygon)
-from .utils import (flatten,
-                    from_raw_holeless_mix_components,
+from .utils import (from_raw_holeless_mix_components,
                     from_raw_mix_components,
                     from_raw_multipolygon)
 
@@ -897,13 +896,11 @@ class Multipolygon(Indexable, Shaped):
             raise ValueError('Duplicate polygons found.')
         for polygon in self._polygons:
             polygon.validate()
-        polygons_raw_edges = list(flatten(
-                chain(to_pairs_sequence(polygon.border.raw()),
-                      flatten(to_pairs_sequence(hole.raw())
-                              for hole in polygon.holes))
-                for polygon in self._polygons))
+        polygons_raw_edges = list(flatten(polygon_to_raw_edges(polygon)
+                                          for polygon in self._polygons))
         if segments_cross_or_overlap(polygons_raw_edges,
-                                     accurate=False):
+                                     accurate=False,
+                                     validate=False):
             raise ValueError('Polygons should only touch each other '
                              'in discrete number of points.')
 
