@@ -39,6 +39,9 @@ from gon.compound import (Compound,
                           Shaped)
 from gon.core.arithmetic import (non_negative_min,
                                  robust_divide)
+from gon.core.iterable import (flatten,
+                               to_pairs_iterable,
+                               to_pairs_sequence)
 from gon.degenerate import EMPTY
 from gon.discrete import Multipoint
 from gon.geometry import Geometry
@@ -59,19 +62,16 @@ from gon.linear.raw import (raw_segment_point_distance,
                             raw_segments_distance,
                             squared_raw_point_segment_distance,
                             squared_raw_segments_distance)
-from gon.linear.utils import (from_raw_multisegment,
-                              to_pairs_iterable,
-                              to_pairs_sequence)
+from gon.linear.utils import from_raw_multisegment
 from gon.primitive import (Point,
                            RawPoint)
 from gon.primitive.point import point_to_step
 from .hints import (RawMultipolygon,
                     RawPolygon)
-from .utils import (flatten,
-                    from_raw_holeless_mix_components,
+from .utils import (from_raw_holeless_mix_components,
                     from_raw_mix_components,
                     from_raw_multipolygon,
-                    to_convex_hull)
+                    to_raw_points_convex_hull)
 
 
 class Polygon(Indexable, Shaped):
@@ -555,7 +555,9 @@ class Polygon(Indexable, Shaped):
         """
         return (self
                 if self.is_convex
-                else Polygon(Contour(to_convex_hull(self._border.vertices))))
+                else
+                Polygon(Contour.from_raw(
+                        to_raw_points_convex_hull(self._raw_border))))
 
     @property
     def holes(self) -> List[Contour]:
@@ -912,9 +914,15 @@ class Polygon(Indexable, Shaped):
             for hole in self._holes:
                 hole.validate()
             relation = region_in_multiregion(self._raw_border, self._raw_holes)
-            if (relation is not Relation.COVER
-                    and relation is not Relation.ENCLOSES):
-                raise ValueError('Holes should lie inside border.')
+            if not (relation is Relation.COVER
+                    or relation is Relation.ENCLOSES):
+                raise ValueError('Holes should lie inside the border.')
+            border_minus_holes = subtract_multipolygons(
+                    [(self._raw_border, [])],
+                    [(raw_hole, []) for raw_hole in self._raw_holes])
+            if (len(border_minus_holes) != 1
+                    or Polygon.from_raw(border_minus_holes[0]) != self):
+                raise ValueError('Holes should not tear polygon apart.')
 
     def _distance_to_raw_point(self, other: RawPoint) -> Coordinate:
         return (raw_segment_point_distance(
